@@ -1,9 +1,6 @@
 context("errorGen")
 
 test_that("errorGen works", {
-	skip_on_cran()
-	skip_on_travis()
-	skip_on_appveyor()
 	
 	validation.data <- data.frame(rnorm(10, mean = 0.2, sd = 1))
 	names(validation.data) <- c("validation")
